// java wrapper for vtkSimpleMotionBlurPass object
//

package vtk;
import vtk.*;

public class vtkSimpleMotionBlurPass extends vtkDepthImageProcessingPass
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReleaseGraphicsResources_2(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_2(id0); }

  private native int GetSubFrames_3();
  public int GetSubFrames()
    { return GetSubFrames_3(); }

  private native void SetSubFrames_4(int id0);
  public void SetSubFrames(int id0)
    { SetSubFrames_4(id0); }

  private native void SetDepthFormat_5(int id0);
  public void SetDepthFormat(int id0)
    { SetDepthFormat_5(id0); }

  private native void SetColorFormat_6(int id0);
  public void SetColorFormat(int id0)
    { SetColorFormat_6(id0); }

  private native long GetDepthTexture_7();
  public vtkTextureObject GetDepthTexture() {
    long temp = GetDepthTexture_7();

    if (temp == 0) return null;
    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorTexture_8();
  public vtkTextureObject GetColorTexture() {
    long temp = GetColorTexture_8();

    if (temp == 0) return null;
    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkSimpleMotionBlurPass() { super(); }

  public vtkSimpleMotionBlurPass(long id) { super(id); }
  public native long   VTKInit();

}
